# Monotone Layers

Documents are available at [https://ibm.github.io/pmlayer/](https://ibm.github.io/pmlayer/)


# Citation

Please consider citing this paper.
- H. Yanagisawa, K. Miyaguchi, and T. Katsuki, "Hierarchical Lattice Layer for Partially Monotone Regression," NeurIPS 2022.
